@@ -83,10 +83,18 @@ def CreateHeader():
             h=h+"\n"+"No alarm set"
         h=h+"\n"+"Alarm Time Window Start: "+strftime(data.dateformat,records.AlarmTimeWindowStart_tuple)
         h=h+"\n"+"Alarm Time Window End: "+strftime(data.dateformat,records.AlarmTimeWindowEnd_tuple)
+        h=h+"\n"+"Alarm Use external: "+str(data.UseAlternativeAlarm)
+        if(data.UseAlternativeAlarm==True):
+            h=h+"\n"+"Alarm External: "+str(data.AlternativeAlarm)
+        else:
+            h=h+"\n"+"Alarm External: "
+
     else:
         h=h+"\n"+"No alarm set"
         h=h+"\n"+"Alarm Time Window Start: Not set"
         h=h+"\n"+"Alarm Time Window End: Not set"
+        h=h+"\n"+"Alarm Use external: False"
+        h=h+"\n"+"Alarm External: "
 
     h=h+"\n"+"Note: "+str(records.Note.encode( "utf-8" ))
 
@@ -273,14 +281,24 @@ def LoadRecord():
                 records.AlarmTimeWindow_minutes=int((records.AlarmTimeWindowEnd_seconds-records.AlarmTimeWindowStart_seconds)/60)
                 if(records.AlarmTimeWindowStart_tuple!=-1): records.AlarmIsSet=True
 
-           #process header line 6
+            if(records.SWversion>=2.1):
+                #process header line 6
+                tmp=file.readline()
+                tmp=string.replace(tmp[:-1], "Alarm Use external: ",  "")
+                if(tmp=="False"): records.UseAlternativeAlarm=False
+                else: records.UseAlternativeAlarm=True
+
+                #process header line 7
+                tmp=file.readline()
+                records.AlternativeAlarm=string.replace(tmp[:-1], "Alarm External: ",  "")
+
+           #process header line 8
             tmp=file.readline()
             records.Note=string.replace(tmp[:-1].decode("utf-8"), "Note: ",  "")
 
 
-
             if(records.SWversion>=2.0):
-                #process header line 7..10
+                #process header line 9..12
                 tmp=file.readline()
                 tmp=string.replace(tmp[:-1], "Lucid dream song start: ",  "")
                 if(tmp=="Not set"):
@@ -305,7 +323,7 @@ def LoadRecord():
                     records.Lucid_Dream_Song_Volume=int(string.replace(tmp[:-1], "Lucid dream song volume: ",  ""))
 
 
-                #process header line 11..14
+                #process header line 13..16
                 tmp=file.readline()
                 tmp=string.replace(tmp[:-1], "WakeUp song start: ",  "")
                 if(tmp=="Not set"):
@@ -329,7 +347,7 @@ def LoadRecord():
 
 
             if(records.SWversion>=2.0):
-                #spare lines 15..19
+                #spare lines 17..21
                 tmp=file.readline() #drop line
                 tmp=file.readline() #drop line
                 tmp=file.readline() #drop line
@@ -337,7 +355,7 @@ def LoadRecord():
                 tmp=file.readline() #drop line
 
 
-          #process header line 20
+          #process header line 22
             tmp=file.readline()  #not used, column header
 
 
@@ -351,7 +369,7 @@ def LoadRecord():
         return 8
 
 
-#    PrintRecordData()
+    PrintRecordData()
 
 
     records.Index=0
